[vlc-commits] macosx: Rename VLCVoutWindowController to VLCVideoOutputProvider

David Fuhrmann git at videolan.org
Sun Jun 10 11:03:13 CEST 2018


vlc | branch: master | David Fuhrmann <dfuhrmann at videolan.org> | Sun Jun 10 10:57:03 2018 +0200| [04e8c62ccbe43c4ab99bc93b0230a18e7dc655c9] | committer: David Fuhrmann

macosx: Rename VLCVoutWindowController to VLCVideoOutputProvider

This better matches the naming scheme, as WindowController is typically
used to have one designated window which is controlled.

> http://git.videolan.org/gitweb.cgi/vlc.git/?a=commit;h=04e8c62ccbe43c4ab99bc93b0230a18e7dc655c9
---

 .../package/macosx/VLC.xcodeproj/project.pbxproj   | 12 ++++----
 modules/gui/macosx/Makefile.am                     |  2 +-
 .../gui/macosx/VLCAudioEffectsWindowController.m   |  2 +-
 modules/gui/macosx/VLCBookmarksWindowController.m  |  2 +-
 modules/gui/macosx/VLCCoreInteraction.m            |  2 +-
 modules/gui/macosx/VLCMain.h                       |  4 +--
 modules/gui/macosx/VLCMain.m                       |  4 +--
 modules/gui/macosx/VLCMainMenu.m                   |  4 +--
 modules/gui/macosx/VLCMainWindow.m                 | 18 ++++++------
 modules/gui/macosx/VLCPlaylistInfo.m               |  2 +-
 modules/gui/macosx/VLCResumeDialogController.m     |  2 +-
 .../VLCTrackSynchronizationWindowController.m      |  2 +-
 .../gui/macosx/VLCVideoEffectsWindowController.m   |  2 +-
 ...WindowController.h => VLCVideoOutputProvider.h} |  4 +--
 ...WindowController.m => VLCVideoOutputProvider.m} | 32 +++++++++++-----------
 modules/gui/macosx/Windows.m                       |  8 +++---
 po/POTFILES.in                                     |  4 +--
 17 files changed, 53 insertions(+), 53 deletions(-)

diff --git a/extras/package/macosx/VLC.xcodeproj/project.pbxproj b/extras/package/macosx/VLC.xcodeproj/project.pbxproj
index c5738cf800..fe0ee17e5f 100644
--- a/extras/package/macosx/VLC.xcodeproj/project.pbxproj
+++ b/extras/package/macosx/VLC.xcodeproj/project.pbxproj
@@ -63,6 +63,7 @@
 		1C31140D1E508C8800D4DD76 /* SPMediaKeyTap.m in Sources */ = {isa = PBXBuildFile; fileRef = CCF0777C13659A8000AF19FD /* SPMediaKeyTap.m */; };
 		1C5716AC1F5B142200678627 /* coreaudio_common.c in Sources */ = {isa = PBXBuildFile; fileRef = 1C5716AB1F5B142200678627 /* coreaudio_common.c */; };
 		1C69FDF61EAB30C7007724ED /* Windows.m in Sources */ = {isa = PBXBuildFile; fileRef = E06CF7F516020F6200C698B7 /* Windows.m */; };
+		1CAC3EE820CD1B3B00613DB2 /* VLCVideoOutputProvider.m in Sources */ = {isa = PBXBuildFile; fileRef = 1CAC3EE620CD1B3B00613DB2 /* VLCVideoOutputProvider.m */; };
 		1CCC88EC2078A3D500E5626F /* MainMenu.xib in Sources */ = {isa = PBXBuildFile; fileRef = 6B8224091E4D2A9000833BE1 /* MainMenu.xib */; };
 		1CCC88ED2078A3D500E5626F /* MainWindow.xib in Sources */ = {isa = PBXBuildFile; fileRef = 6B82240A1E4D2A9000833BE1 /* MainWindow.xib */; };
 		1CCC88EE2078A3D500E5626F /* VLCStatusBarIconMainMenu.xib in Sources */ = {isa = PBXBuildFile; fileRef = 6B82241A1E4D2A9000833BE1 /* VLCStatusBarIconMainMenu.xib */; };
@@ -105,7 +106,6 @@
 		6B7F1FDF1F07DA920002BDD8 /* VLCHexNumberFormatter.m in Sources */ = {isa = PBXBuildFile; fileRef = 6B7F1FDE1F07DA920002BDD8 /* VLCHexNumberFormatter.m */; };
 		6B8166291EBFC34300C26F1B /* VLCDefaultValueSlider.m in Sources */ = {isa = PBXBuildFile; fileRef = 6B6A499B1DFD9B23009128AC /* VLCDefaultValueSlider.m */; };
 		6B81662A1EBFC34300C26F1B /* VLCDefaultValueSliderCell.m in Sources */ = {isa = PBXBuildFile; fileRef = 6B6A499D1DFD9B23009128AC /* VLCDefaultValueSliderCell.m */; };
-		6B81662B1EBFC35D00C26F1B /* VLCVoutWindowController.m in Sources */ = {isa = PBXBuildFile; fileRef = E0C2583F161B593D00185AAD /* VLCVoutWindowController.m */; };
 		6B81662C1EBFC38100C26F1B /* VLCUIWidgets.m in Sources */ = {isa = PBXBuildFile; fileRef = 5CCED71514C0D4A90057F8D1 /* VLCUIWidgets.m */; };
 		6BBB05DA1EEFEA29003A1019 /* VLCHUDOutlineView.m in Sources */ = {isa = PBXBuildFile; fileRef = 6BBB05D91EEFEA29003A1019 /* VLCHUDOutlineView.m */; };
 		6BBB05E01EEFF165003A1019 /* VLCHUDTableCornerView.m in Sources */ = {isa = PBXBuildFile; fileRef = 6BBB05DF1EEFF165003A1019 /* VLCHUDTableCornerView.m */; };
@@ -152,6 +152,8 @@
 		1C67C8A71D58C0A40079E1C1 /* VLCAboutWindowController.m */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.c.objc; path = VLCAboutWindowController.m; sourceTree = "<group>"; };
 		1C7CB91A1D787E7600388902 /* VLCPopupPanelController.h */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.c.h; path = VLCPopupPanelController.h; sourceTree = "<group>"; };
 		1C7CB91B1D787E7600388902 /* VLCPopupPanelController.m */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.c.objc; path = VLCPopupPanelController.m; sourceTree = "<group>"; };
+		1CAC3EE620CD1B3B00613DB2 /* VLCVideoOutputProvider.m */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.c.objc; path = VLCVideoOutputProvider.m; sourceTree = "<group>"; };
+		1CAC3EE720CD1B3B00613DB2 /* VLCVideoOutputProvider.h */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.c.h; path = VLCVideoOutputProvider.h; sourceTree = "<group>"; };
 		1CAEBBFF1E1EC0A400A99E49 /* VLCFSPanelDraggableView.h */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.c.h; path = VLCFSPanelDraggableView.h; sourceTree = "<group>"; };
 		1CAEBC001E1EC0A400A99E49 /* VLCFSPanelDraggableView.m */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.c.objc; path = VLCFSPanelDraggableView.m; sourceTree = "<group>"; };
 		1CC25CA71B2C585D0003F994 /* darwinvlc.m */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.c.objc; name = darwinvlc.m; path = ../../../bin/darwinvlc.m; sourceTree = "<group>"; };
@@ -517,8 +519,6 @@
 		E0382C01160BA09E0031D7FF /* VLCControlsBarCommon.m */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.c.objc; path = VLCControlsBarCommon.m; sourceTree = "<group>"; };
 		E06CF7F416020F6200C698B7 /* Windows.h */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.c.h; path = Windows.h; sourceTree = "<group>"; };
 		E06CF7F516020F6200C698B7 /* Windows.m */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.c.objc; path = Windows.m; sourceTree = "<group>"; };
-		E0C2583E161B593D00185AAD /* VLCVoutWindowController.h */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.c.h; path = VLCVoutWindowController.h; sourceTree = "<group>"; };
-		E0C2583F161B593D00185AAD /* VLCVoutWindowController.m */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.c.objc; path = VLCVoutWindowController.m; sourceTree = "<group>"; };
 /* End PBXFileReference section */
 
 /* Begin PBXFrameworksBuildPhase section */
@@ -1100,8 +1100,8 @@
 			children = (
 				CCCCDCA01413E1C000FE3DE1 /* VLCVoutView.h */,
 				CCCCDCA11413E1C000FE3DE1 /* VLCVoutView.m */,
-				E0C2583E161B593D00185AAD /* VLCVoutWindowController.h */,
-				E0C2583F161B593D00185AAD /* VLCVoutWindowController.m */,
+				1CAC3EE720CD1B3B00613DB2 /* VLCVideoOutputProvider.h */,
+				1CAC3EE620CD1B3B00613DB2 /* VLCVideoOutputProvider.m */,
 			);
 			name = "Video Output";
 			sourceTree = "<group>";
@@ -1537,7 +1537,6 @@
 				1CCC89062078A3D500E5626F /* TimeSelectionPanel.xib in Sources */,
 				6B81662C1EBFC38100C26F1B /* VLCUIWidgets.m in Sources */,
 				6B0AB0F11F1AC8B3003A1B4E /* VLCSliderCell.m in Sources */,
-				6B81662B1EBFC35D00C26F1B /* VLCVoutWindowController.m in Sources */,
 				6B8166291EBFC34300C26F1B /* VLCDefaultValueSlider.m in Sources */,
 				6B81662A1EBFC34300C26F1B /* VLCDefaultValueSliderCell.m in Sources */,
 				1C69FDF61EAB30C7007724ED /* Windows.m in Sources */,
@@ -1583,6 +1582,7 @@
 				1C3113B41E508C6900D4DD76 /* VLCInputManager.m in Sources */,
 				1C3113B61E508C6900D4DD76 /* VLCMain+OldPrefs.m in Sources */,
 				1C3113B81E508C6900D4DD76 /* VLCMain.m in Sources */,
+				1CAC3EE820CD1B3B00613DB2 /* VLCVideoOutputProvider.m in Sources */,
 				1C3113BA1E508C6900D4DD76 /* VLCApplication.m in Sources */,
 				1C3113BC1E508C6900D4DD76 /* VLCKeyboardBacklightControl.m in Sources */,
 				1C3113BD1E508C6900D4DD76 /* macosx.m in Sources */,
diff --git a/modules/gui/macosx/Makefile.am b/modules/gui/macosx/Makefile.am
index bba7d44d03..ace16e1aca 100644
--- a/modules/gui/macosx/Makefile.am
+++ b/modules/gui/macosx/Makefile.am
@@ -65,7 +65,7 @@ libmacosx_plugin_la_SOURCES = \
 	gui/macosx/VLCUIWidgets.h gui/macosx/VLCUIWidgets.m \
 	gui/macosx/VLCScrollingClipView.h gui/macosx/VLCScrollingClipView.m \
 	gui/macosx/VLCStatusBarIcon.h gui/macosx/VLCStatusBarIcon.m \
-	gui/macosx/VLCVoutWindowController.h gui/macosx/VLCVoutWindowController.m \
+	gui/macosx/VLCVideoOutputProvider.h gui/macosx/VLCVideoOutputProvider.m \
 	gui/macosx/Windows.h gui/macosx/Windows.m \
 	gui/macosx/VLCAudioEffectsWindowController.h gui/macosx/VLCAudioEffectsWindowController.m \
 	gui/macosx/VLCBookmarksWindowController.h gui/macosx/VLCBookmarksWindowController.m \
diff --git a/modules/gui/macosx/VLCAudioEffectsWindowController.m b/modules/gui/macosx/VLCAudioEffectsWindowController.m
index a1ad903aa1..139dde510d 100644
--- a/modules/gui/macosx/VLCAudioEffectsWindowController.m
+++ b/modules/gui/macosx/VLCAudioEffectsWindowController.m
@@ -352,7 +352,7 @@
     if ([self.window isKeyWindow])
         [self.window orderOut:sender];
     else {
-        [self.window setLevel: [[[VLCMain sharedInstance] voutController] currentStatusWindowLevel]];
+        [self.window setLevel: [[[VLCMain sharedInstance] voutProvider] currentStatusWindowLevel]];
         [self.window makeKeyAndOrderFront:sender];
     }
 }
diff --git a/modules/gui/macosx/VLCBookmarksWindowController.m b/modules/gui/macosx/VLCBookmarksWindowController.m
index ff2229860a..7f74aae84c 100644
--- a/modules/gui/macosx/VLCBookmarksWindowController.m
+++ b/modules/gui/macosx/VLCBookmarksWindowController.m
@@ -107,7 +107,7 @@
     if ([self.window isVisible])
         [self.window orderOut:sender];
     else {
-        [self.window setLevel: [[[VLCMain sharedInstance] voutController] currentStatusWindowLevel]];
+        [self.window setLevel: [[[VLCMain sharedInstance] voutProvider] currentStatusWindowLevel]];
         [self.window makeKeyAndOrderFront:sender];
     }
 }
diff --git a/modules/gui/macosx/VLCCoreInteraction.m b/modules/gui/macosx/VLCCoreInteraction.m
index 28484dcd9f..a5247385e1 100644
--- a/modules/gui/macosx/VLCCoreInteraction.m
+++ b/modules/gui/macosx/VLCCoreInteraction.m
@@ -694,7 +694,7 @@ static int BossCallback(vlc_object_t *p_this, const char *psz_var,
         vlc_object_release(p_vout);
     } else { // e.g. lion fullscreen toggle
         BOOL b_fs = var_ToggleBool(pl_Get(p_intf), "fullscreen");
-        [[[VLCMain sharedInstance] voutController] setFullscreen:b_fs forWindow:nil withAnimation:YES];
+        [[[VLCMain sharedInstance] voutProvider] setFullscreen:b_fs forWindow:nil withAnimation:YES];
     }
 }
 
diff --git a/modules/gui/macosx/VLCMain.h b/modules/gui/macosx/VLCMain.h
index ffe2b4c0d4..9ece125e59 100644
--- a/modules/gui/macosx/VLCMain.h
+++ b/modules/gui/macosx/VLCMain.h
@@ -40,7 +40,7 @@
 #import <Cocoa/Cocoa.h>
 #import "misc.h"
 #import "VLCMainWindow.h"
-#import "VLCVoutWindowController.h"
+#import "VLCVideoOutputProvider.h"
 #import "VLCStatusBarIcon.h"
 #import "VLCStringUtility.h"
 
@@ -79,7 +79,7 @@ static NSString * VLCMediaKeySupportSettingChangedNotification = @"VLCMediaKeySu
 
 @interface VLCMain : NSObject <NSWindowDelegate, NSApplicationDelegate>
 
- at property (readonly) VLCVoutWindowController* voutController;
+ at property (readonly) VLCVideoOutputProvider* voutProvider;
 @property (readonly) BOOL nativeFullscreenMode;
 @property (nonatomic, readwrite) BOOL playlistUpdatedSelectorInQueue;
 
diff --git a/modules/gui/macosx/VLCMain.m b/modules/gui/macosx/VLCMain.m
index 443076ffaa..80eb6acf27 100644
--- a/modules/gui/macosx/VLCMain.m
+++ b/modules/gui/macosx/VLCMain.m
@@ -231,7 +231,7 @@ static VLCMain *sharedInstance = nil;
         _mainmenu = [[VLCMainMenu alloc] init];
         _statusBarIcon = [[VLCStatusBarIcon  alloc] init];
 
-        _voutController = [[VLCVoutWindowController alloc] init];
+        _voutProvider = [[VLCVideoOutputProvider alloc] init];
         _playlist = [[VLCPlaylist alloc] init];
 
         _mainWindowController = [[NSWindowController alloc] initWithWindowNibName:@"MainWindow"];
@@ -350,7 +350,7 @@ static VLCMain *sharedInstance = nil;
     [[NSNotificationCenter defaultCenter] removeObserver: self];
 
     // closes all open vouts
-    _voutController = nil;
+    _voutProvider = nil;
 
     /* write cached user defaults to disk */
     [[NSUserDefaults standardUserDefaults] synchronize];
diff --git a/modules/gui/macosx/VLCMainMenu.m b/modules/gui/macosx/VLCMainMenu.m
index cc1f088c7a..de286d2fb2 100644
--- a/modules/gui/macosx/VLCMainMenu.m
+++ b/modules/gui/macosx/VLCMainMenu.m
@@ -682,7 +682,7 @@
     config_PutInt("macosx-show-playback-buttons", b_value);
 
     [(VLCMainWindowControlsBar *)[[[VLCMain sharedInstance] mainWindow] controlsBar] toggleJumpButtons];
-    [[[VLCMain sharedInstance] voutController] updateWindowsUsingBlock:^(VLCVideoWindowCommon *window) {
+    [[[VLCMain sharedInstance] voutProvider] updateWindowsUsingBlock:^(VLCVideoWindowCommon *window) {
         [[window controlsBar] toggleForwardBackwardMode: b_value];
     }];
 
@@ -1242,7 +1242,7 @@
 
 - (IBAction)showPreferences:(id)sender
 {
-    NSInteger i_level = [[[VLCMain sharedInstance] voutController] currentStatusWindowLevel];
+    NSInteger i_level = [[[VLCMain sharedInstance] voutProvider] currentStatusWindowLevel];
     [[[VLCMain sharedInstance] simplePreferences] showSimplePrefsWithLevel:i_level];
 }
 
diff --git a/modules/gui/macosx/VLCMainWindow.m b/modules/gui/macosx/VLCMainWindow.m
index 1cc9bcb8d6..32f330c181 100644
--- a/modules/gui/macosx/VLCMainWindow.m
+++ b/modules/gui/macosx/VLCMainWindow.m
@@ -47,7 +47,7 @@
 
 #import "VLCMainWindowControlsBar.h"
 #import "VLCVoutView.h"
-#import "VLCVoutWindowController.h"
+#import "VLCVideoOutputProvider.h"
 
 
 @interface VLCMainWindow() <PXSourceListDataSource, PXSourceListDelegate, NSOutlineViewDataSource, NSOutlineViewDelegate, NSWindowDelegate, NSAnimationDelegate, NSSplitViewDelegate>
@@ -572,7 +572,7 @@ static const float f_min_window_height = 307.;
     [self.controlsBar updateTimeSlider];
     [self.fspanel updatePositionAndTime];
 
-    [[[VLCMain sharedInstance] voutController] updateControlsBarsUsingBlock:^(VLCControlsBarCommon *controlsBar) {
+    [[[VLCMain sharedInstance] voutProvider] updateControlsBarsUsingBlock:^(VLCControlsBarCommon *controlsBar) {
         [controlsBar updateTimeSlider];
     }];
 
@@ -602,12 +602,12 @@ static const float f_min_window_height = 307.;
         NSURL * o_url = [NSURL URLWithString:toNSStr(uri)];
         if ([o_url isFileURL]) {
             [self setRepresentedURL: o_url];
-            [[[VLCMain sharedInstance] voutController] updateWindowsUsingBlock:^(VLCVideoWindowCommon *o_window) {
+            [[[VLCMain sharedInstance] voutProvider] updateWindowsUsingBlock:^(VLCVideoWindowCommon *o_window) {
                 [o_window setRepresentedURL:o_url];
             }];
         } else {
             [self setRepresentedURL: nil];
-            [[[VLCMain sharedInstance] voutController] updateWindowsUsingBlock:^(VLCVideoWindowCommon *o_window) {
+            [[[VLCMain sharedInstance] voutProvider] updateWindowsUsingBlock:^(VLCVideoWindowCommon *o_window) {
                 [o_window setRepresentedURL:nil];
             }];
         }
@@ -622,7 +622,7 @@ static const float f_min_window_height = 307.;
 
         if ([aString length] > 0) {
             [self setTitle: aString];
-            [[[VLCMain sharedInstance] voutController] updateWindowsUsingBlock:^(VLCVideoWindowCommon *o_window) {
+            [[[VLCMain sharedInstance] voutProvider] updateWindowsUsingBlock:^(VLCVideoWindowCommon *o_window) {
                 [o_window setTitle:aString];
             }];
 
@@ -642,7 +642,7 @@ static const float f_min_window_height = 307.;
 - (void)updateWindow
 {
     [self.controlsBar updateControls];
-    [[[VLCMain sharedInstance] voutController] updateControlsBarsUsingBlock:^(VLCControlsBarCommon *controlsBar) {
+    [[[VLCMain sharedInstance] voutProvider] updateControlsBarsUsingBlock:^(VLCControlsBarCommon *controlsBar) {
         [controlsBar updateControls];
     }];
 
@@ -678,7 +678,7 @@ static const float f_min_window_height = 307.;
     [self.controlsBar setPause];
     [self.fspanel setPause];
 
-    [[[VLCMain sharedInstance] voutController] updateControlsBarsUsingBlock:^(VLCControlsBarCommon *controlsBar) {
+    [[[VLCMain sharedInstance] voutProvider] updateControlsBarsUsingBlock:^(VLCControlsBarCommon *controlsBar) {
         [controlsBar setPause];
     }];
 }
@@ -688,7 +688,7 @@ static const float f_min_window_height = 307.;
     [self.controlsBar setPlay];
     [self.fspanel setPlay];
 
-    [[[VLCMain sharedInstance] voutController] updateControlsBarsUsingBlock:^(VLCControlsBarCommon *controlsBar) {
+    [[[VLCMain sharedInstance] voutProvider] updateControlsBarsUsingBlock:^(VLCControlsBarCommon *controlsBar) {
         [controlsBar setPlay];
     }];
 }
@@ -735,7 +735,7 @@ static const float f_min_window_height = 307.;
         }
 
         [self makeFirstResponder: _playlistScrollView];
-        [[[VLCMain sharedInstance] voutController] updateWindowLevelForHelperWindows: NSNormalWindowLevel];
+        [[[VLCMain sharedInstance] voutProvider] updateWindowLevelForHelperWindows: NSNormalWindowLevel];
 
         // restore alpha value to 1 for the case that macosx-opaqueness is set to < 1
         [self setAlphaValue:1.0];
diff --git a/modules/gui/macosx/VLCPlaylistInfo.m b/modules/gui/macosx/VLCPlaylistInfo.m
index 646790746b..04fc4f7c4f 100644
--- a/modules/gui/macosx/VLCPlaylistInfo.m
+++ b/modules/gui/macosx/VLCPlaylistInfo.m
@@ -131,7 +131,7 @@
     if ([self.window isKeyWindow])
         [self.window orderOut:sender];
     else {
-        [self.window setLevel: [[[VLCMain sharedInstance] voutController] currentStatusWindowLevel]];
+        [self.window setLevel: [[[VLCMain sharedInstance] voutProvider] currentStatusWindowLevel]];
         [self.window makeKeyAndOrderFront:sender];
     }
 }
diff --git a/modules/gui/macosx/VLCResumeDialogController.m b/modules/gui/macosx/VLCResumeDialogController.m
index 23882dfbf7..be4208e9de 100644
--- a/modules/gui/macosx/VLCResumeDialogController.m
+++ b/modules/gui/macosx/VLCResumeDialogController.m
@@ -76,7 +76,7 @@
                                                        userInfo:nil
                                                         repeats:YES];
 
-    [w setLevel:[[[VLCMain sharedInstance] voutController] currentStatusWindowLevel]];
+    [w setLevel:[[[VLCMain sharedInstance] voutProvider] currentStatusWindowLevel]];
     [w center];
 
     [w makeKeyAndOrderFront:nil];
diff --git a/modules/gui/macosx/VLCTrackSynchronizationWindowController.m b/modules/gui/macosx/VLCTrackSynchronizationWindowController.m
index 8c2ceaa79d..bf822fd64a 100644
--- a/modules/gui/macosx/VLCTrackSynchronizationWindowController.m
+++ b/modules/gui/macosx/VLCTrackSynchronizationWindowController.m
@@ -97,7 +97,7 @@
     if ([self.window isVisible])
         [self.window orderOut:sender];
     else {
-        [self.window setLevel: [[[VLCMain sharedInstance] voutController] currentStatusWindowLevel]];
+        [self.window setLevel: [[[VLCMain sharedInstance] voutProvider] currentStatusWindowLevel]];
         [self.window makeKeyAndOrderFront:sender];
 
         [self updateValues];
diff --git a/modules/gui/macosx/VLCVideoEffectsWindowController.m b/modules/gui/macosx/VLCVideoEffectsWindowController.m
index c7f7a368c5..bb1df42687 100644
--- a/modules/gui/macosx/VLCVideoEffectsWindowController.m
+++ b/modules/gui/macosx/VLCVideoEffectsWindowController.m
@@ -757,7 +757,7 @@
     if ([self.window isKeyWindow])
         [self.window orderOut:sender];
     else {
-        [self.window setLevel: [[[VLCMain sharedInstance] voutController] currentStatusWindowLevel]];
+        [self.window setLevel: [[[VLCMain sharedInstance] voutProvider] currentStatusWindowLevel]];
         [self.window makeKeyAndOrderFront:sender];
     }
 }
diff --git a/modules/gui/macosx/Windows.m b/modules/gui/macosx/Windows.m
index 194b5de2f3..dd15cf2370 100644
--- a/modules/gui/macosx/Windows.m
+++ b/modules/gui/macosx/Windows.m
@@ -604,7 +604,7 @@
 
     NSInteger i_currLevel = [self level];
     // self.fullscreen and _inFullscreenTransition must not be true yet
-    [[[VLCMain sharedInstance] voutController] updateWindowLevelForHelperWindows: NSNormalWindowLevel];
+    [[[VLCMain sharedInstance] voutProvider] updateWindowLevelForHelperWindows: NSNormalWindowLevel];
     [self setLevel:NSNormalWindowLevel];
     i_originalLevel = i_currLevel;
 
@@ -682,7 +682,7 @@
 {
     _inFullscreenTransition = NO;
 
-    [[[VLCMain sharedInstance] voutController] updateWindowLevelForHelperWindows: i_originalLevel];
+    [[[VLCMain sharedInstance] voutProvider] updateWindowLevelForHelperWindows: i_originalLevel];
     [self setLevel:i_originalLevel];
 }
 
@@ -720,7 +720,7 @@
     /* Make sure we don't see the window flashes in float-on-top mode */
     NSInteger i_currLevel = [self level];
     // self.fullscreen must not be true yet
-    [[[VLCMain sharedInstance] voutController] updateWindowLevelForHelperWindows: NSNormalWindowLevel];
+    [[[VLCMain sharedInstance] voutProvider] updateWindowLevelForHelperWindows: NSNormalWindowLevel];
     [self setLevel:NSNormalWindowLevel];
     i_originalLevel = i_currLevel; // would be overwritten by previous call
 
@@ -984,7 +984,7 @@
 
     o_fullscreen_window = nil;
 
-    [[[VLCMain sharedInstance] voutController] updateWindowLevelForHelperWindows: i_originalLevel];
+    [[[VLCMain sharedInstance] voutProvider] updateWindowLevelForHelperWindows: i_originalLevel];
     [self setLevel:i_originalLevel];
 
     [self setAlphaValue: config_GetFloat("macosx-opaqueness")];
diff --git a/po/POTFILES.in b/po/POTFILES.in
index 3764dbf1be..96b9f67617 100644
--- a/po/POTFILES.in
+++ b/po/POTFILES.in
@@ -558,8 +558,8 @@ modules/gui/macosx/VLCVolumeSliderCell.h
 modules/gui/macosx/VLCVolumeSliderCell.m
 modules/gui/macosx/VLCVoutView.h
 modules/gui/macosx/VLCVoutView.m
-modules/gui/macosx/VLCVoutWindowController.h
-modules/gui/macosx/VLCVoutWindowController.m
+modules/gui/macosx/VLCVideoOutputProvider.h
+modules/gui/macosx/VLCVideoOutputProvider.m
 modules/gui/macosx/VLCWrappableTextField.h
 modules/gui/macosx/VLCWrappableTextField.m
 modules/gui/macosx/Windows.h



More information about the vlc-commits mailing list
diff --git a/modules/gui/macosx/VLCVoutWindowController.h b/modules/gui/macosx/VLCVideoOutputProvider.h
similarity index 95%
rename from modules/gui/macosx/VLCVoutWindowController.h
rename to modules/gui/macosx/VLCVideoOutputProvider.h
index d144708eab..63fa57ec0b 100644
--- a/modules/gui/macosx/VLCVoutWindowController.h
+++ b/modules/gui/macosx/VLCVideoOutputProvider.h
@@ -1,5 +1,5 @@
 /*****************************************************************************
  * VLCVoutWindowController.h: MacOS X interface module
  *****************************************************************************
  * Copyright (C) 2012-2014 VLC authors and VideoLAN
  * $Id$
@@ -31,7 +31,7 @@
 @class VLCVideoWindowCommon;
 @class VLCVoutView;
 
- at interface VLCVoutWindowController : NSObject
+ at interface VLCVideoOutputProvider : NSObject
 
 @property (readonly, nonatomic) NSInteger currentStatusWindowLevel;
 
@@ -1,5 +1,5 @@
 /*****************************************************************************
- * VLCVoutWindowController.h: MacOS X interface module
+ * VLCVideoOutputProvider.h: MacOS X interface module
  *****************************************************************************
  * Copyright (C) 2012-2014 VLC authors and VideoLAN
diff --git a/modules/gui/macosx/VLCVoutWindowController.m b/modules/gui/macosx/VLCVideoOutputProvider.m
similarity index 95%
rename from modules/gui/macosx/VLCVoutWindowController.m
rename to modules/gui/macosx/VLCVideoOutputProvider.m
index 4c84c9aebc..8597559ce3 100644
--- a/modules/gui/macosx/VLCVoutWindowController.m
+++ b/modules/gui/macosx/VLCVideoOutputProvider.m
@@ -1,5 +1,5 @@
 /*****************************************************************************
  * VLCVoutWindowController.m: MacOS X interface module
  *****************************************************************************
  * Copyright (C) 2012-2014 VLC authors and VideoLAN
  * $Id$
@@ -25,7 +25,7 @@
 #include <vlc_vout_display.h>
 
 #import "CompatibilityFixes.h"
-#import "VLCVoutWindowController.h"
+#import "VLCVideoOutputProvider.h"
 #import "VLCMain.h"
 #import "VLCMainWindow.h"
 #import "VLCVoutView.h"
@@ -55,15 +55,15 @@ int WindowOpen(vout_window_t *p_wnd, const vout_window_cfg_t *cfg)
 
         NSRect proposedVideoViewPosition = NSMakeRect(cfg->x, cfg->y, cfg->width, cfg->height);
 
-        VLCVoutWindowController *voutController = [[VLCMain sharedInstance] voutController];
-        if (!voutController) {
+        VLCVideoOutputProvider *voutProvider = [[VLCMain sharedInstance] voutProvider];
+        if (!voutProvider) {
             return VLC_EGENERIC;
         }
 
         __block VLCVoutView *videoView = nil;
 
         dispatch_sync(dispatch_get_main_queue(), ^{
-            videoView = [voutController setupVoutForWindow:p_wnd
+            videoView = [voutProvider setupVoutForWindow:p_wnd
                              withProposedVideoViewPosition:proposedVideoViewPosition];
         });
 
@@ -84,8 +84,8 @@ int WindowOpen(vout_window_t *p_wnd, const vout_window_cfg_t *cfg)
 static int WindowControl(vout_window_t *p_wnd, int i_query, va_list args)
 {
     @autoreleasepool {
-        VLCVoutWindowController *voutController = [[VLCMain sharedInstance] voutController];
-        if (!voutController) {
+        VLCVideoOutputProvider *voutProvider = [[VLCMain sharedInstance] voutProvider];
+        if (!voutProvider) {
             return VLC_EGENERIC;
         }
 
@@ -105,7 +105,7 @@ static int WindowControl(vout_window_t *p_wnd, int i_query, va_list args)
                     i_cooca_level = NSStatusWindowLevel;
 
                 dispatch_async(dispatch_get_main_queue(), ^{
-                    [voutController setWindowLevel:i_cooca_level forWindow:p_wnd];
+                    [voutProvider setWindowLevel:i_cooca_level forWindow:p_wnd];
                 });
 
                 break;
@@ -116,7 +116,7 @@ static int WindowControl(vout_window_t *p_wnd, int i_query, va_list args)
                 unsigned int i_height = va_arg(args, unsigned int);
 
                 dispatch_async(dispatch_get_main_queue(), ^{
-                    [voutController setNativeVideoSize:NSMakeSize(i_width, i_height)
+                    [voutProvider setNativeVideoSize:NSMakeSize(i_width, i_height)
                                              forWindow:p_wnd];
                 });
 
@@ -134,7 +134,7 @@ static int WindowControl(vout_window_t *p_wnd, int i_query, va_list args)
                 BOOL b_animation = YES;
 
                 dispatch_async(dispatch_get_main_queue(), ^{
-                    [voutController setFullscreen:i_full
+                    [voutProvider setFullscreen:i_full
                                         forWindow:p_wnd
                                     withAnimation:b_animation];
                 });
@@ -143,7 +143,7 @@ static int WindowControl(vout_window_t *p_wnd, int i_query, va_list args)
             }
             case VOUT_WINDOW_HIDE_MOUSE:
             {
-                [voutController hideMouseForWindow:p_wnd];
+                [voutProvider hideMouseForWindow:p_wnd];
                 break;
             }
             default:
@@ -161,18 +161,18 @@ static int WindowControl(vout_window_t *p_wnd, int i_query, va_list args)
 void WindowClose(vout_window_t *p_wnd)
 {
     @autoreleasepool {
-        VLCVoutWindowController *voutController = [[VLCMain sharedInstance] voutController];
-        if (!voutController) {
+        VLCVideoOutputProvider *voutProvider = [[VLCMain sharedInstance] voutProvider];
+        if (!voutProvider) {
             return;
         }
 
         dispatch_async(dispatch_get_main_queue(), ^{
-            [voutController removeVoutForDisplay:[NSValue valueWithPointer:p_wnd]];
+            [voutProvider removeVoutForDisplay:[NSValue valueWithPointer:p_wnd]];
         });
     }
 }
 
- at interface VLCVoutWindowController ()
+ at interface VLCVideoOutputProvider ()
 {
     NSMutableDictionary *voutWindows;
     VLCKeyboardBacklightControl *keyboardBacklight;
@@ -187,7 +187,7 @@ void WindowClose(vout_window_t *p_wnd)
 }
 @end
 
- at implementation VLCVoutWindowController
+ at implementation VLCVideoOutputProvider
 
 - (id)init
 {
@@ -1,5 +1,5 @@
 /*****************************************************************************
- * VLCVoutWindowController.m: MacOS X interface module
+ * VLCVideoOutputProvider.m: MacOS X interface module
  *****************************************************************************
  * Copyright (C) 2012-2014 VLC authors and VideoLAN